'use strict';

exports.__esModule = true;
exports.default = createInjectParamTypes;
function createInjectParamTypes(t, injectPrefixRaw, typeForAnnotations, functionsWithJsx, filename, addDisplayName) {
    var injectPrefix = injectPrefixRaw || '_r';
    var argId = t.identifier(injectPrefix + '1');
    var flagsId = t.identifier(injectPrefix + '2');
    var fileId = t.identifier(injectPrefix + '3');
    var displayNameId = t.identifier('displayName');

    return function injectParamTypes(rawTypes, target, node) {
        var body = [];
        var type = node.type;
        var isJsx = functionsWithJsx.has(node);

        if (rawTypes.length) {
            var types = void 0;
            if (isJsx) {
                types = rawTypes.length > 1 ? [rawTypes[1]] : [];
            } else {
                types = rawTypes;
            }
            var typeArgs = typeForAnnotations(types, node.typeParameters ? node.typeParameters.params : null);
            if (typeArgs.length) {
                body.push(t.expressionStatement(t.assignmentExpression('=', t.memberExpression(target, argId), t.arrayExpression(typeArgs))));
            }

            for (var i = 0; i < types.length; i++) {
                var argType = types[i];
                var decorators = argType.decorators || [];
                for (var j = 0; j < decorators.length; j++) {
                    body.push(t.expressionStatement(t.callExpression(decorators[j].expression, [target, t.identifier('null'), t.identifier(i.toString())])));
                }
            }
        }

        if (type === 'FunctionDeclaration' || type === 'FunctionExpression' || type === 'ArrowFunctionExpression') {
            body.push(t.expressionStatement(t.assignmentExpression('=', t.memberExpression(target, flagsId), t.numericLiteral(isJsx ? 1 : 2))));
        }

        if (filename) {
            body.push(t.expressionStatement(t.assignmentExpression('=', t.memberExpression(target, fileId), t.stringLiteral(filename))));
        }

        if (addDisplayName) {
            body.push(t.expressionStatement(t.assignmentExpression('=', t.memberExpression(target, displayNameId), t.stringLiteral(target.name))));
        }

        return body;
    };
}
//# sourceMappingURL=createInjectParamTypes.js.map